﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Defines asset-management information regarding its parent element.</summary>
    public sealed class AssetTag
    {
        /// <summary>Provides data related to a contributor who worked on the parent element.</summary>
        [XmlElement(ElementName = "contributor")]
        public ContributorTag[] Contributors { get; set; }

        /// <summary>Provides information about the location of the visual scene in physical space.
        /// Element has no attributes, but it can contain 0 or 1 &lt;geographic_location&gt; child
        /// elements.</summary>
        [XmlElement(ElementName = "coverage")]
        public CoverageTag Coverage { get; set; }

        /// <summary>Contains the date and time that the parent element was created. Represented in an ISO
        /// 8601 format as per the XML Schema xs:dateTime primitive type.</summary>
        [XmlElement(ElementName = "created")]
        public DateTime CreatedOn { get; set; }

        /// <summary>Contains a list of words used as search criteria for the parent element.</summary>
        [XmlElement(ElementName = "keywords")]
        public string Keywords { get; set; }

        /// <summary>Contains the date and time that the parent element was last modified. Represented in
        /// an ISO 8601 format as per the XML Schema xs:dateTime primitive type.</summary>
        [XmlElement(ElementName = "modified")]
        public DateTime ModifiedOn { get; set; }

        /// <summary>Contains revision information for the parent element.</summary>
        [XmlElement(ElementName = "revision")]
        public string Revision { get; set; }

        /// <summary>Contains a description of the topical subject of the parent element.</summary>
        [XmlElement(ElementName = "subject")]
        public string Subject { get; set; }

        /// <summary>Contains title information for the parent element.</summary>
        [XmlElement(ElementName = "title")]
        public string Title { get; set; }

        /// <summary>Defines unit of distance for COLLADA elements and objects. This unit of distance applies
        /// to all spatial measurements within the scope of &lt;asset&gt;’s parent element, unless overridden
        /// by a more local &lt;asset&gt;/&lt;unit&gt;.</summary>
        [XmlElement(ElementName = "unit")]
        public UnitTag Unit { get; set; }

        /// <summary>Contains descriptive information about the coordinate system of the geometric data. All
        /// coordinates are right-handed by definition. Valid values are X_UP, Y_UP, or Z_UP.</summary>
        /// <remarks>This element specifies which axis is considered upward, which is considered to the right,
        /// and which is considered inward. See “Details.”</remarks>
        [XmlElement(ElementName = "up_axis")]
        public UpAxis UpAxis { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
