﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Declares the root of the document that contains some of the content in the
    /// COLLADA schema.</summary>
    /// <see cref="http://www.collada.org/mediawiki/index.php/COLLADA_FAQ"/>
    [XmlRoot(ElementName = "COLLADA",
        Namespace = "http://www.collada.org/2008/03/COLLADASchema")]
    public class ColladaDocument
    {
        /// <summary>The COLLADA schema revision with which the instance document conforms.
        /// The only valid value is 1.5.0. Required.</summary>
        [XmlAttribute(AttributeName = "version")]
        public ColladaVersion Version { get; set; }

        /// <summary>Defines asset-management information regarding its parent element.</summary>
        [XmlElement(ElementName = "asset", IsNullable = false)]
        public AssetTag Asset { get; set; }

        /// <summary>Provides a library in which to place &lt;force_field&gt; elements.</summary>
        [XmlElement(ElementName = "library_force_fields")]
        public Physics.LibraryForceFieldsTag[] ForceFields { get; set; }

        /// <summary>Provides a library in which to place &lt;physics_material&gt; elements.</summary>
        [XmlElement(ElementName = "library_physics_materials")]
        public Physics.LibraryPhysicsMaterialsTag[] PhysicsMaterials { get; set; }

        /// <summary>Provides a library in which to place &lt;physics_model&gt; elements.</summary>
        [XmlElement(ElementName = "library_physics_models")]
        public Physics.LibraryPhysicsModelsTag[] PhysicsModels { get; set; }

        /// <summary>Provides a library in which to place &lt;physics_scene&gt; elements.</summary>
        [XmlElement(ElementName = "library_physics_scenes")]
        public Physics.LibraryPhysicsScenesTag[] PhysicsScenes { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
