﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Defines authoring information for asset management.</summary>
    public sealed class ContributorTag
    {
        /// <summary>Contains a string with the author's name.</summary>
        [XmlElement(ElementName = "author")]
        public string Author { get; set; }

        /// <summary>Contains a string with the author's full email address compliant
        /// with RFC 2822 section 3.4.</summary>
        [XmlElement(ElementName = "author_email")]
        public string AuthorEmail { get; set; }

        /// <summary>Contains an xs:anyURI for the URL of this contributor's website.</summary>
        [XmlElement(ElementName = "author_website", DataType = "anyURI")]
        public string AuthorWebsite { get; set; }

        /// <summary>Contains a string with the name of the authoring tool.</summary>
        [XmlElement(ElementName = "authoring_tool")]
        public string AuthoringTool { get; set; }

        /// <summary>Contains a string with comments from this contributor.</summary>
        [XmlElement(ElementName = "comments")]
        public string Comments { get; set; }

        /// <summary>Contains a string with copyright information.</summary>
        [XmlElement(ElementName = "copyright")]
        public string Copyright { get; set; }

        /// <summary>Contains a URI reference (xs:anyURI) to the source data used for this asset.</summary>
        [XmlElement(ElementName = "source_data", DataType = "anyURI")]
        public string SourceData { get; set; }
    }
}
