﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Describes the control vertices (CVs) of a spline.</summary>
    /// <remarks>
    ///     <para>Information about both a control vertex and its related segment are stored on the
    ///     control verticess. Segment data applies to the spline segment that starts at the given
    ///     control vertex.</para>
    ///     <para>Each control vertex must provide a position. It is strongly suggested that you provide
    ///     a source of interpolation methods to be used on the segment that starts at this control
    ///     vertex. Otherwise, the linear interpolation is assumed. For Bézier and Hermite interpolations,
    ///     input and output tangents must be provided for each control vertex.</para>
    ///     <para>Additionally, each control vertex may have an arbitrary amount user-specific information,
    ///     through custom data sources. The custom data sources must provide enough data to have one value
    ///     – however large – for each control vertex.</para>
    /// </remarks>
    public sealed class ControlVerticesTag
    {
        /// <summary>At least one &lt;input&gt; (unshared) element must have a semantic attribute whose
        /// value is POSITION.</summary>
        [XmlElement(ElementName = "input", IsNullable = false)]
        public UnsharedInputTag Input { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
