﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Defines geographic location information regarding the parent of the &lt;asset&gt;
    /// element in which it resides.</summary>
    public sealed class GeographicLocationTag
    {
        /// <summary>Contains a floating-point number that specifies the longitude of the
        /// asset as defined by the WGS 84 world geodetic system.</summary>
        /// <remarks>Valid values range from -180.0 to 180.0.</remarks>
        [XmlElement(ElementName = "longitude")]
        public double Longitude { get; set; }

        /// <summary>Contains a floating-point number that specifies the latitude of the
        /// asset as defined by the WGS 84 world geodetic system.</summary>
        /// <remarks>Valid values range from -90.0 to 90.0.</remarks>
        [XmlElement(ElementName = "latitude")]
        public double Latitude { get; set; }

        /// <summary>Specifies the altitude of the asset as a floating-point number. Altitude
        /// follows the Keyhole Markup Language (KML) standard rather than the WGS 84
        /// calculation of height.</summary>
        /// <remarks>That is, it can be relative to terrain, or relative to sea level.</remarks>
        [XmlElement(ElementName = "altitude")]
        public AltitudeTag Altitude { get; set; }
    }
}
