﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Instantiates a COLLADA geometry resource.</summary>
    /// <remarks>
    ///     <para>The &lt;instance_geometry&gt; element instantiates an object described by a
    ///     &lt;geometry&gt; element. A geometry object is instantiated within the local coordinate
    ///     system of its parent &lt;node&gt; or &lt;shape&gt; and that determines its position,
    ///     orientation, and scale. COLLADA supports convex mesh, mesh, and spline primitives.</para>
    ///     <para>For details about instance elements in COLLADA, see "Instantiation and External
    ///     Referencing" in Chapter 3: Schema Concepts.</para>
    /// </remarks>
    public sealed class InstanceGeometryTag
    {
        /// <summary>A text string value containing the scoped identifier of this element. This value must
        /// be unique within the scope of the parent element.</summary>
        /// <remarks>Optional. For details, see "Address Syntax" in Chapter 3: Schema Concepts.</remarks>
        [XmlAttribute(AttributeName = "sid")]
        public string ScopedId { get; set; }

        /// <summary>The text string name of this element.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "name", DataType = "token")]
        public string Name { get; set; }

        /// <summary>The URL of the location of the &lt;geometry&gt; element to instantiate.</summary>
        /// <remarks>Required. Can refer to a local instance or external reference.</remarks>
        [XmlAttribute(AttributeName = "url", DataType = "anyURI")]
        public string Url { get; set; }

        // TODO: There is no reference to <bind_material> here because it's not applicable to
        // the current work I'm doing - but you'll need to add it if you start needing these
        // classes to parse collada FX/GLSL tags

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
