﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Contains or refers to information sufficient to describe basic geometric meshes.</summary>
    /// <remarks>
    ///     <para>The definition of &lt;convex_mesh&gt; is identical to &lt;mesh&gt; except that, instead
    ///     of a complete description (&lt;source&gt;, &lt;vertices&gt;, &lt;polygons&gt;, and so on), it
    ///     may simply point to another &lt;geometry&gt; to derive its shape. The latter case means that
    ///     the convex hull of that &lt;geometry&gt; should be computed and is indicated by the optional
    ///     convex_hull_of attribute.</para>
    ///     <para>This is very useful because it allows for reusing a &lt;mesh&gt; (that is used for
    ///     rendering) for physics to minimize the document size and to maintain a link to the original
    ///     &lt;mesh&gt;.</para>
    ///     <para>The minimal way to describe a &lt;convex_mesh&gt; is to specify its vertices (via a
    ///     &lt;vertices&gt; element and its corresponding source) and let the importer compute the
    ///     convex hull of that point cloud.</para>
    /// </remarks>
    public sealed class ConvexMeshTag
    {
        /// <summary>A URI string of a &lt;geometry&gt;. If specified, compute the convex hull of the
        /// specified mesh; in this case, your application should ignore &lt;source&gt; and &lt;vertices&gt;,
        /// if specified.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "convex_hull_of", DataType = "anyURI")]
        public string ConvexHull { get; set; }

        // TODO: Many elements needed here!

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
