﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Declares a cylinder primitive that is centered around its local origin and aligned along
    /// its local y axis.</summary>
    /// <remarks>Geometric primitives, also called analytical shapes, are mostly useful for collision
    /// shapes for physics.</remarks>
    public sealed class CylinderTag
    {
        /// <summary>Contains a floating-point value that represents the length of the line
        /// segment connecting the centers of the capping hemispheres (ellipsoids).</summary>
        [XmlElement(ElementName = "height", IsNullable = false)]
        public double Height { get; set; }

        /// <summary>Contains three floating-point values that represent the x, y, and z radii
        /// of the capsule (it may be elliptical).</summary>
        [XmlElement(ElementName = "radius", IsNullable = false)]
        public string Radius { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
