﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Provides the interface to a constraint that is created by instantiating a physics model
    /// that has a constraint.</summary>
    /// <remarks>
    ///     <para>A rigid constraint between two rigid bodies has a number of properties than can be
    ///     adjusted at runtime to add additional variety to the simulation. For example, animation
    ///     data from an articulated model can be used to update the attachment frame alignments on the
    ///     corresponding joints. If these joints have a maximum torque, this would provide an
    ///     elementary physically based character motion system.</para>
    ///     <para>For general information about instance elements in COLLADA, see "Instantiation and
    ///     External Referencing" in Chapter 3: Schema Concepts.</para>
    /// </remarks>
    public sealed class InstanceRigidBodyConstraintTag
    {
        /// <summary>A text string value containing the scoped identifier of this element. This value must
        /// be unique within the scope of the parent element.</summary>
        /// <remarks>Optional. For details, see "Address Syntax" in Chapter 3: Schema Concepts.</remarks>
        [XmlAttribute(AttributeName = "sid")]
        public string ScopedId { get; set; }

        /// <summary>AThe text string name of this element.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "name", DataType = "token")]
        public string Name { get; set; }

        /// <summary>A reference to the SID of the &lt;rigid_body&gt; to instantiate.</summary>
        /// <remarks>Required.</remarks>
        [XmlAttribute(AttributeName = "constraint")]
        public string Constraint { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
