﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Provides a library in which to place &lt;force_field&gt; elements.</summary>
    /// <remarks>
    ///     <para>Some applications use force fields to influence the motion of rigid bodies.</para>
    ///     <para>As data sets become larger and more complex, they become harder to manipulate
    ///     within a single container. One approach to managing this complexity is to divide the
    ///     data into smaller pieces organized by some criteria. These modular pieces can then be
    ///     stored in separate resources as libraries.</para>
    /// </remarks>
    public sealed class LibraryForceFieldsTag
    {
        /// <summary>A text string containing the unique identifier of the &lt;library_force_field&gt;
        /// element. This value must be unique within the instance document.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "id", DataType = "ID")]
        public string Id { get; set; }

        /// <summary>The text string name of this element.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "name", DataType = "token")]
        public string Name { get; set; }

        /// <summary>Defines asset-management information regarding its parent element.</summary>
        [XmlElement(ElementName = "asset")]
        public AssetTag Asset { get; set; }

        /// <summary>Provides a general container for force fields.</summary>
        [XmlElement(ElementName = "force_field", IsNullable = false)]
        public ForceFieldTag[] ForceFields { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
