﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    public class MassFrameTag
    {
        /// <summary>Specifies the center of mass and the alignment of the principal axes of the
        /// rigid_body using COLLADA’s mechanism for expressing transformations. Because there
        /// can be multiple &lt;translate&gt; and &lt;rotate&gt; entries in any order, the affine parts of
        /// the resulting transformation must be extracted. This final translation and rotation
        /// correspond to the center of mass and the principle axes, respectively.</summary>
        [XmlChoiceIdentifier(MemberName = "TransformTypes")]
        [XmlElement(ElementName = "translate", Type = typeof(ScopedIdTag<string>))]
        [XmlElement(ElementName = "rotate", Type = typeof(ScopedIdTag<string>))]
        public object[] Transforms { get; set; }

        /// <summary>Describes what choice of the transforms specified</summary>
        [XmlIgnore]
        public TransformType[] TransformTypes { get; set; }
    }
}
