﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Specifies physics-material information for the common profile that all
    /// COLLADA implementations must support.</summary>
    public sealed class PhysicsMaterialCommonTag
    {
        /// <summary>Contains a floating-point number that specifies the dynamic
        /// friction coefficient.</summary>
        [XmlElement(ElementName = "dynamic_friction")]
        public ScopedIdTag<double> DynamicFriction { get; set; }

        /// <summary>Contains a floating-point number that is the proportion of the
        /// kinetic energy preserved in the impact (typically ranges from 0.0 to 1.0).
        /// Also known as "bounciness" or "elasticity."</summary>
        [XmlElement(ElementName = "restitution")]
        public ScopedIdTag<double> Restitution { get; set; }

        /// <summary>Contains a floating-point number that specifies the static friction
        /// coefficient.</summary>
        [XmlElement(ElementName = "static_friction")]
        public ScopedIdTag<double> StaticFriction { get; set; }
    }
}
