﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Allows for building complex combinations of rigid bodies and constraints
    /// that may be instantiated multiple times.</summary>
    public sealed class PhysicsModelTag
    {
        /// <summary>A text string containing the unique identifier of the element. This value must
        /// be unique within the instance document.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "id")]
        public string Id { get; set; }

        /// <summary>The text string name of this element.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "name")]
        public string Name { get; set; }

        /// <summary>Defines asset-management information regarding its parent element.</summary>
        [XmlElement(ElementName = "asset")]
        public AssetTag Asset { get; set; }

        /// <summary>Defines a &lt;rigid_body&gt; element and sets its nondefault properties.</summary>
        [XmlElement(ElementName = "rigid_body")]
        public RigidBodyTag[] RigidBodies { get; set; }

        /// <summary>Defines a &lt;rigid_constraint&gt; element and allows for overriding
        /// some or all of its properties.</summary>
        [XmlElement(ElementName = "rigid_constraint")]
        public RigidConstraintTag[] RigidConstraints { get; set; }

        /// <summary>Instantiates a physics model from the given url, and assigns an sid to it,
        /// to distinguish it from other child elements.</summary>
        [XmlElement(ElementName = "instance_physics_model")]
        public InstancePhysicsModelTag[] InstancePhysicsModels { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
