﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Specifies physics-scene information for the common profile that all COLLADA
    /// implementations must support.</summary>
    public sealed class PhysicsSceneCommonTag
    {
        /// <summary>A vector representation of the scene's gravity force field. It is given as
        /// a denormalized direction vector of three floating-point values that indicate both the
        /// magnitude and direction of acceleration caused by the field.</summary>
        [XmlElement(ElementName = "gravity")]
        public ScopedIdTag<string> Gravity { get; set; }

        /// <summary>The integration time step, measured in seconds, of the physics scene. This
        /// value is engine-specific. If omitted, the physics engine’s default is used. Contains a
        /// floating-point number.</summary>
        [XmlElement(ElementName = "time_step")]
        public ScopedIdTag<double> TimeStep { get; set; }
    }
}
