﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Defines an attachment frame of reference, to a rigid body or a node, within a
    /// rigid constraint.</summary>
    /// <remarks>
    ///     <para>A &lt;rigid_constraint&gt; attaches (and limits the motion between) two rigid bodies
    ///     together. &lt;ref_attachment&gt; refers to the first rigid body, and &lt;attachment&gt; to
    ///     the second. For example, in the case of a hinge constraint between a door and a wall, one
    ///     of them is the reference attachment (in this case, the wall), and the other is the
    ///     attachment (the door).</para>
    ///     <para>The &lt;ref_attachment&gt; also defines the local coordinate frame for that end of
    ///     the connection, relative to the rigid body (or node), using &lt;translate&gt; and
    ///     &lt;rotate&gt; elements. For example, you attach the hinge (rigid constraint) to the
    ///     middle of the edge of the wall (rigid body), relative to the wall’s local origin.</para>
    /// </remarks>
    public sealed class RefAttachmentTag : MassFrameTag
    {
        /// <summary>A scoped-identifier reference to a &lt;rigid_body&gt; or &lt;node&gt;. This
        /// must refer to the SID of a &lt;rigid_body&gt; either in &lt;attachment&gt; or in
        /// &lt;ref_attachment&gt;; they cannot both be &lt;node&gt;s.</summary>
        /// <remarks>Required.</remarks>
        [XmlElement(ElementName = "rigid_body", DataType = "anyURI")]
        public string RigidBody { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
