﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom.Physics
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Specifies rigid-body information for the common profile that every COLLADA
    /// implmentation must support.</summary>
    public sealed class RigidBodyCommonTag
    {
        /// <summary>Contains a Boolean that specifies whether the rigid_body is movable.</summary>
        [XmlElement(ElementName = "dynamic")]
        public ScopedIdTag<bool> Dynamic { get; set; }

        /// <summary>Contains a floating-point value that specifies the total mass of
        /// the rigid_body.</summary>
        [XmlElement(ElementName = "mass")]
        public ScopedIdTag<double> Mass { get; set; }

        /// <summary>Contains three floating-point numbers, which are the diagonal elements of the
        /// inertia tensor matrix for the rigid body as aligned with its principle axes. With this
        /// alignment the off-diagonal elements of the tensor matrix are zero.</summary>
        [XmlElement(ElementName = "inertia")]
        public ScopedIdTag<string> Inertia { get; set; }

        /// <summary>Specifies the center of mass and the alignment of the principal axes of the
        /// rigid_body using COLLADA’s mechanism for expressing transformations. Because there
        /// can be multiple &lt;translate&gt; and &lt;rotate&gt; entries in any order, the affine parts of
        /// the resulting transformation must be extracted. This final translation and rotation
        /// correspond to the center of mass and the principle axes, respectively.</summary>
        [XmlElement(ElementName = "mass_frame")]
        public MassFrameTag MassFrame { get; set; }

        /// <summary>Defines or references a physics_material for the rigid_body.</summary>
        [XmlChoiceIdentifier(MemberName = "MaterialType")]
        [XmlElement(ElementName = "physics_material", Type = typeof(PhysicsMaterialTag))]
        [XmlElement(ElementName = "instance_physics_material", Type = typeof(InstancePhysicsMaterialTag))]
        public object Material { get; set; }

        /// <summary>Describes what choice of material is specified</summary>
        [XmlIgnore]
        public MaterialType MaterialType { get; set; }

        /// <summary>Describes components of a &lt;rigid_body&gt;.</summary>
        [XmlElement(ElementName = "shape")]
        public ShapeTag Shape { get; set; }
    }
}
