﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Embodies the entire set of information that can be visualized from the contents of
    /// a COLLADA resource.</summary>
    /// <remarks>
    ///     <para>Each COLLADA document can contain, at most, one &lt;scene&gt; element.</para>
    ///     <para>The &lt;scene&gt; element declares the base of the scene hierarchy or scene graph.
    ///     The scene contains elements that provide much of the visual and transformational
    ///     information content as created by the authoring tools.</para>
    ///     <para>The hierarchical structure of the scene is organized into a scene graph. A scene graph
    ///     is a directed acyclic graph (DAG) or tree data structure that contains nodes of visual
    ///     information and related data. The structure of the scene graph contributes to optimal
    ///     processing and rendering of the data and is therefore widely used in the computer
    ///     graphics domain.</para>
    /// </remarks> 
    public sealed class SceneTag
    {
        /// <summary>Instantiates an object described by a &lt;physics_scene&gt; element.</summary>
        [XmlElement(ElementName = "instance_physics_scene")]
        public Physics.InstancePhysicsSceneTag[] PhysicsScenes { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag Extra { get; set; }
    }
}
