﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Declares a data repository that provides values according to the semantics of an
    /// &lt;input&gt; element that refers to it.</summary>
    /// <remarks>
    ///     <para>A data source is a well-known source of information that can be accessed through
    ///     an established communication channel.</para>
    ///     <para>The data source provides access methods to the information. These access methods
    ///     implement various techniques according to the representation of the information. The
    ///     information may be stored locally as an array of data or a program that generates the
    ///     data.</para>
    /// </remarks>
    public sealed class SourceTag
    {
        /// <summary>A text string containing the unique identifier of the element. This value must
        /// be unique within the instance document.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "id", DataType = "ID")]
        public string Id { get; set; }

        /// <summary>The text string name of this element.</summary>
        /// <remarks>Optional.</remarks>
        [XmlAttribute(AttributeName = "name", DataType = "token")]
        public string Name { get; set; }

        /// <summary>Defines asset-management information regarding its parent element.</summary>
        [XmlElement(ElementName = "asset")]
        public AssetTag Asset { get; set; }

        /// <summary>A data array element.</summary>
        [XmlChoiceIdentifier(MemberName = "ArrayElementType")]
        [XmlElement(ElementName = "bool_array", Type = typeof(ArrayTag))]
        [XmlElement(ElementName = "float_array", Type = typeof(FloatArrayTag))]
        [XmlElement(ElementName = "IDREF_array", Type = typeof(ArrayTag))]
        [XmlElement(ElementName = "int_array", Type = typeof(IntArrayTag))]
        [XmlElement(ElementName = "Name_array", Type = typeof(ArrayTag))]
        [XmlElement(ElementName = "SIDREF_array", Type = typeof(ArrayTag))]
        [XmlElement(ElementName = "token_array", Type = typeof(ArrayTag))]
        public object ArrayElement { get; set; }

        [XmlIgnore]
        public ArrayElementType ArrayElementType { get; set; }

        /// <summary>Specifies source information for the common profile that all COLLADA
        /// implementations must support.</summary>
        [XmlElement(ElementName = "technique_common")]
        public SourceCommonTag Common { get; set; }

        /// <summary>Declares the information used to process some portion of the content.</summary>
        [XmlElement(ElementName = "technique", IsNullable = false)]
        public TechniqueTag[] Techniques { get; set; }
    }
}
