﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Describes a multisegment spline with control vertex (CV) and segment information.</summary>
    /// <remarks>The organization of &lt;spline&gt; is very similar to that of &lt;mesh&gt;. A &lt;spline&gt;
    /// contains &lt;source&gt; elements that provide the attributes and a &lt;control_vertices&gt; element
    /// to "assemble" the attribute streams. Information about each segment is stored with the information
    /// about its preceding control vertex.</remarks>
    public sealed class SplineTag
    {
        /// <summary>Whether there is a segment connecting the first and last control vertices. The
        /// default is false, indicating that the spline is open.</summary>
        [XmlAttribute(AttributeName = "closed")]
        public bool Closed { get; set; }

        /// <summary>Provides the values for the CVs and segments of the spline.</summary>
        [XmlElement(ElementName = "source", IsNullable = false)]
        public SourceTag[] Sources { get; set; }

        /// <summary>Describes the CVs of the spline.</summary>
        [XmlElement(ElementName = "control_vertices", IsNullable = false)]
        public ControlVerticesTag ControlVertices { get; set; }

        /// <summary>Provides arbitrary additional information about or related to its parent element.</summary>
        [XmlElement(ElementName = "extra")]
        public ExtraTag[] Extras { get; set; }
    }
}
