﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.ColladaDom
{
    // .NET Fx
    using System;
    using System.Xml.Serialization;

    /// <summary>Contains descriptive information about the coordinate system of the geometric data. All
    /// coordinates are right-handed by definition. Valid values are X_UP, Y_UP, or Z_UP.</summary>
    public sealed class UnitTag
    {
        /// <summary>The name (xs:NMTOKEN) of the distance unit. For example, "meter", "centimeter",
        /// "inches", or "parsec". This can be the real name of a measurement, or an imaginary
        /// name.</summary>
        [XmlElement(ElementName = "name", DataType = "NMTOKEN")]
        public string Name { get; set; }

        /// <summary>How many real-world meters in one distance unit as a floating-point number. For
        /// example, 1.0 for the name "meter"; 1000 for the name "kilometer"; 0.3048 for the name
        /// "foot".</summary>
        [XmlElement(ElementName = "meter")]
        public double Meters { get; set; }
    }
}
