﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics.TestGame.Screens
{
    // .NET Fx
    using System;
    using System.Collections.Generic;

    // XNA
    using Microsoft.Xna.Framework;
    using Microsoft.Xna.Framework.Graphics;

    // Local
    using JohnWells.GameDynamics.Geometries;
    using JohnWells.GameDynamics.Constraints;

    internal sealed class ForceScreen : TestScreen
    {
        #region Fields
        // Private variables
        private Simulation simulation;

        // Content
        private ModelMesh ball;
        #endregion

        public ForceScreen(MyGame game)
            : base(game, "Content")
        {
        }

        #region Properties
        public override string Description
        {
            get { return "Force screen - Various balls getting forces applied"; }
        }
        #endregion

        #region Methods
        public override void Initialize()
        {
            base.Initialize();
            this.simulation = new Simulation();
            this.simulation.Gravity = Vector3.Zero;
            var r = new Random();

            // Top left
            {
                var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
                var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
                var roll = (float)r.NextDouble() * MathHelper.TwoPi;
                var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
                orientation.Normalize();

                var state = new Transform(new Vector3(-4f, 2f, 0f), orientation);
                var body = new Sphere(state, Material.Metal, 1f);
                this.simulation.Add(body);

				var relative = new Vector3(-1f, 0f, 0f);
				var force = new Vector3(0f, -10f, 0f);// Vector3.Transform(new Vector3(0f, -10f, 0f), Quaternion.Conjugate(orientation));
				//body.ApplyForce(position, force);
				body.ApplyForce(relative, force);
			}

            // Top Middle
            {
                var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
                var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
                var roll = (float)r.NextDouble() * MathHelper.TwoPi;
                var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
                orientation.Normalize();

                var state = new Transform(new Vector3(0f, 2f, 0f), orientation);
                var body = new Sphere(state, Material.Metal, 1f);
                this.simulation.Add(body);

                body.ApplyForce(new Vector3(0f, 0f, 0f), new Vector3(0f, -10f, 0f));
            }
			
            // Top Right
            {
                var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
                var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
                var roll = (float)r.NextDouble() * MathHelper.TwoPi;
                var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
                orientation.Normalize();

                var state = new Transform(new Vector3(4f, 2f, 0f), orientation);
                var body = new Sphere(state, Material.Metal, 1f);
                this.simulation.Add(body);

				var position = state.Translation - Vector3.UnitX;
				var force = new Vector3(0f, -10f, 0f);
				body.ApplyForce(position, force);
            }
        }

        protected override void LoadContent()
        {
            base.LoadContent();

            this.ball = this.Content.Load<Model>("BeachBall").Meshes["Ball"];
            foreach (BasicEffect item in this.ball.Effects)
            {
                item.View = Matrix.CreateLookAt(
                    new Vector3(0f, 0f, 15f),
                    new Vector3(0f, 0f, 0f),
                    Vector3.Up);

                item.Projection = Matrix.CreatePerspectiveFieldOfView(
                    MathHelper.ToRadians(45f),
                    this.GraphicsDevice.Viewport.AspectRatio,
                    1f,
                    10000f);

                item.EnableDefaultLighting();
            }

            GC.Collect();
        }

        public override void Update(GameTime gameTime)
        {
            base.Update(gameTime);
            this.simulation.Update(gameTime.ElapsedGameTime);
        }

        public override void Draw(GameTime gameTime)
        {
            base.Draw(gameTime);

            this.GraphicsDevice.RenderState.DepthBufferEnable = true;
            foreach (var body in this.simulation.GetEnumerator())
            {
                foreach (BasicEffect effect in this.ball.Effects)
                    effect.World = body.State;

                this.ball.Draw();
            }
        }
        #endregion
    }
}