﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics.TestGame.Screens
{
    // .NET Fx
    using System;
    using System.Collections.Generic;

    // XNA
    using Microsoft.Xna.Framework;
    using Microsoft.Xna.Framework.Graphics;

    // Local
    using JohnWells.GameDynamics.Geometries;
    using JohnWells.GameDynamics.Constraints;

    internal sealed class GravityTestScreen : TestScreen
    {
        #region Fields
        // Private variables
        private Simulation simulation;
        private Body body;
        private TimeSpan? started;

        // Content
        private ModelMesh ball;
        #endregion

        public GravityTestScreen(MyGame game)
            : base(game, "Content")
        {
        }

        #region Properties
        public override string Description
        {
            get { return "Gravity Test"; }
        }
        #endregion

        #region Methods
        public override void Initialize()
        {
            base.Initialize();
            this.simulation = new Simulation();
            var r = new Random();

            this.simulation.Gravity = Vector3.Down * 9.82f;

            var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
            var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
            var roll = (float)r.NextDouble() * MathHelper.TwoPi;
            var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
            orientation.Normalize();

            var state = new Transform(Vector3.Zero, orientation);
            this.body = new Sphere(state, Material.Metal, 1f);
            this.simulation.Add(this.body);

            this.started = null;
        }

        protected override void LoadContent()
        {
            base.LoadContent();

            this.ball = this.Content.Load<Model>("BeachBall").Meshes["Ball"];
            foreach (BasicEffect item in this.ball.Effects)
            {
                item.View = Matrix.CreateLookAt(
                    new Vector3(0f, -120f, 290f),
                    new Vector3(0f, -120f, 0f),
                    Vector3.Up);

                item.Projection = Matrix.CreatePerspectiveFieldOfView(
                    MathHelper.ToRadians(45f),
                    this.GraphicsDevice.Viewport.AspectRatio,
                    1f,
                    10000f);

                item.EnableDefaultLighting();
            }

            GC.Collect();
        }

        public override void Update(GameTime gameTime)
        {
            if (!this.started.HasValue)
                this.started = gameTime.TotalRealTime;

            var elapsed = gameTime.TotalRealTime - (TimeSpan)this.started;
            if (elapsed.TotalSeconds < 2.5f)
                Console.WriteLine(string.Format("{0},{1}", elapsed.TotalMilliseconds, this.body.Velocity.Y));

            base.Update(gameTime);
            this.simulation.Update(gameTime.ElapsedGameTime);
        }

        public override void Draw(GameTime gameTime)
        {
            base.Draw(gameTime);

            this.GraphicsDevice.RenderState.DepthBufferEnable = true;
            foreach (var body in this.simulation.GetEnumerator())
            {
                foreach (BasicEffect effect in this.ball.Effects)
                    effect.World = body.State;

                this.ball.Draw();
            }
        }
        #endregion
    }
}