﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics.TestGame.Screens
{
    // .NET Fx
    using System;
    using System.Collections.Generic;

    // XNA
    using Microsoft.Xna.Framework;
    using Microsoft.Xna.Framework.Graphics;

    // Local
    using JohnWells.GameDynamics.Geometries;
    using JohnWells.GameDynamics.Constraints;
 
    internal sealed class OpposingBallsScreen : TestScreen
    {
        #region Fields
        // Private variables
        private Simulation simulation;

        // Content
        private ModelMesh ball; 
        #endregion

        public OpposingBallsScreen(MyGame game)
            : base(game, "Content")
        {
        }

        #region Properties
        public override string Description
        {
            get { return "Opposing Balls - Various balls hitting each other"; }
        }
        #endregion

        #region Methods
        public override void Initialize()
        {
            base.Initialize();
            this.simulation = new Simulation();
            this.simulation.Gravity = Vector3.Zero;
            var r = new Random();

            // Top Left-hand beach ball
            {
                var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
                var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
                var roll = (float)r.NextDouble() * MathHelper.TwoPi;
                var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
                orientation.Normalize();

                var position = new Vector3(-5f, 3f, 0f);
                var state = new Transform(position, orientation);
                var body = new Sphere(state, Material.Rubber, 1f);
                body.Velocity = new Vector3(+4f, 0f, 0f);
                this.simulation.Add(body);
            }

            // Top Right-hand beach ball
            {
                var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
                var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
                var roll = (float)r.NextDouble() * MathHelper.TwoPi;
                var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
                orientation.Normalize();

                var position = new Vector3(0f, 3f, 0f);
                var state = new Transform(position, orientation);
                var body = new Sphere(state, Material.Rubber, 1f);
                body.Velocity = new Vector3(0f, 0f, 0f);
                this.simulation.Add(body);
            }

            // Middle Left-hand beach ball
            {
                var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
                var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
                var roll = (float)r.NextDouble() * MathHelper.TwoPi;
                var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
                orientation.Normalize();

                var position = new Vector3(-5f, 0f, 0f);
                var state = new Transform(position, orientation);
                var body = new Sphere(state, Material.Rubber, 1f);
                body.Velocity = new Vector3(+4f, 0f, 0f);
                this.simulation.Add(body);
            }

            // Middle Right-hand beach ball
            {
                var yaw = (float)r.NextDouble() * MathHelper.TwoPi;
                var pitch = (float)r.NextDouble() * MathHelper.TwoPi;
                var roll = (float)r.NextDouble() * MathHelper.TwoPi;
                var orientation = Quaternion.CreateFromYawPitchRoll(yaw, pitch, roll);
                orientation.Normalize();

                var position = new Vector3(+5f, 0f, 0f);
                var state = new Transform(position, orientation);
                var body = new Sphere(state, Material.Rubber, 1f);
                body.Velocity = new Vector3(-4f, 0f, 0f);
                this.simulation.Add(body);
            }
        }

        protected override void LoadContent()
        {
            base.LoadContent();

            this.ball = this.Content.Load<Model>("BeachBall").Meshes["Ball"];
            foreach (BasicEffect item in this.ball.Effects)
            {
                item.View = Matrix.CreateLookAt(
                    new Vector3(0f, 0f, 16f),
                    new Vector3(0f, 0f, 0f),
                    Vector3.Up);

                item.Projection = Matrix.CreatePerspectiveFieldOfView(
                    MathHelper.ToRadians(45f),
                    this.GraphicsDevice.Viewport.AspectRatio,
                    1f,
                    10000f);

                item.EnableDefaultLighting();
            }

            GC.Collect();
        }

        public override void Update(GameTime gameTime)
        {
            base.Update(gameTime);
            //this.simulation.Update(gameTime.ElapsedRealTime);
			this.simulation.Update(TimeSpan.FromMilliseconds(16.6D));
        }

        public override void Draw(GameTime gameTime)
        {
            base.Draw(gameTime);

            this.GraphicsDevice.RenderState.DepthBufferEnable = true;
            foreach (var body in this.simulation.GetEnumerator())
            {
                foreach (BasicEffect effect in this.ball.Effects)
                    effect.World = body.State;

                this.ball.Draw();
            }
        }
        #endregion
    }
}
