﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics.CD
{
    // .NET Fx
    using System;
    using System.Diagnostics;
    using System.Runtime.InteropServices;

    // Local
    using JohnWells.GameDynamics.Geometries;

    public sealed partial class Arbiter
    {
        /// <summary>Used internally to hold references between type pairs and their associated algorithm</summary>
        [StructLayout(LayoutKind.Auto)]
        private struct Entry
        {
            #region Fields
            // Public fields
            public readonly ICollider CD;
            public readonly Type A, B;
            #endregion

            public Entry(ICollider cd, Type a, Type b)
            {
                #region Assertions
                Debug.Assert(cd != null);
                Debug.Assert(a != null);
                Debug.Assert(b != null);
                Debug.Assert(a.IsSubclassOf(typeof(Body)));
                Debug.Assert(b.IsSubclassOf(typeof(Body)));
                #endregion

                this.CD = cd;
                this.A = a;
                this.B = b;
            }
        }
    }
}
