﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics.CD
{
    // .NET Fx
    using System.Diagnostics;

    // XNA
    using Microsoft.Xna.Framework;

    /// <summary>Detects contact between two sphere bodies</summary>
    public sealed class SphereCollider : ICollider
    {
        #region ICollider Members
        Contact? ICollider.Detect(Body a, Body b)
        {
            #region Assertions
            Debug.Assert(a != null);
            Debug.Assert(b != null);
            #endregion

            var ab = a.Radius + b.Radius;

            // Are these two spheres close enough?
            var normal = a.State.Translation - b.State.Translation;
            var distanceSquared = normal.LengthSquared();
            if (distanceSquared > ab * ab)
                return null;

            // Yes, they are in contact
            var position = a.State.Translation - (normal * 0.5f);
            var depth = ab - normal.Length();
            normal = Vector3.Normalize(normal);

            return new Contact(ref position, ref normal, depth);
        }
        #endregion
    }
}
