﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics.Constraints
{
    // .NET Fx
    using System.Diagnostics;

    // XNA
    using Microsoft.Xna.Framework;

    // Local
    using JohnWells.GameDynamics.CD;

    /// <summary>Constrains a body to be a the fixed distance from a given world point</summary>
    public sealed class DistanceConstraint : IConstrained
    {
        #region Fields
        // Private variables
        private readonly Body body;
        private readonly Vector3 bodyAnchor, worldAnchor;
        private readonly float distance;
        #endregion

        public DistanceConstraint(Body body, Vector3 bodyAnchor, Vector3 worldAnchor, float distance)
        {
            #region Assertions
            Debug.Assert(body != null);
            Debug.Assert(!float.IsNaN(distance) && !float.IsInfinity(distance));
            Debug.Assert(distance >= 0f);
            #endregion

            this.body = body;
            this.bodyAnchor = bodyAnchor;
            this.worldAnchor = worldAnchor;
            this.distance = distance; // TODO: Store as sqaured-distance to reduce math?
		}

		#region IConstrained Members
		void IConstrained.ApplyForces()
        {
        }

        void IConstrained.Satisfy()
        {
        }
        #endregion
    }
}
