﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics.Constraints
{
    // .NET Fx
    using System.Diagnostics;
    using System.Runtime.InteropServices;

    // Local
    using JohnWells.GameDynamics.CD;

    /// <summary>Used internally to keep track of short-lived body interpenetration</summary>
    /// <remarks>The IConstrained interface is not implemented on this type because it would create extra boxing</remarks>
    [StructLayout(LayoutKind.Auto)]
    internal struct Penetration
    {
        #region Fields
        // Private variables
        private readonly ICollider cd;
        private readonly Body collider;
        private readonly Body obstacle; 
        #endregion

        public Penetration(ICollider cd, Body collider, Body obstacle)
        {
            #region Assertions
            Debug.Assert(cd != null);
            Debug.Assert(collider != null);
            Debug.Assert(!collider.IsStatic);
            Debug.Assert(obstacle != null);
            #endregion

            this.cd = cd;
            this.collider = collider;
            this.obstacle = obstacle;
        }

        #region Methods
        /// <summary>Resolves interpenetration between the bodies of this constraint by translation the two bodies
        /// out of penetration if needed</summary>
        public void Satisfy()
		{
			// TODO: Instrument
            // Determine if they're still touching (they may be fine now...)
            var result = this.cd.Detect(this.collider, this.obstacle);
            if (!result.HasValue)
                return;

            var contact = result.Value;

            var translation = this.collider.State.Translation + contact.Normal * contact.Depth * 0.5f;
            var orientation = this.collider.State.Orientation;
            this.collider.State = new Transform(translation, orientation);

            // TODO: Split the resolution using mass (heavy colliders displace less than light obstacles)
            // TODO: Use some form of partial orientation correction for physical correctness
        } 
        #endregion
    }
}
