﻿/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics
{
	// .NET Fx
	using System.Diagnostics;

    /// <summary>This type supports the GameDynamics infrastructure and is not intended to be used directly from your code</summary>
	/// <remarks>This class holds counters and methods that appear only in DEBUG builds</remarks>
	internal static class Instrumentation
	{
        #region Nested Struct: Data
        /// <summary>This type supports the GameDynamics infrastructure and is not intended to be used directly from your code</summary>
        public struct Data
        {
            public uint ForcesApplied;
			public uint PenetrationsDetected;
            public uint Updates;
        } 
        #endregion

		#region Fields
        // Public fields
        public static Data Last, Current, Total;
		#endregion

		#region Methods
		/// <summary>Signals that a force has been applied to a body</summary>
		[Conditional("DEBUG")]
		public static void ForceApplied()
		{
            Instrumentation.Current.ForcesApplied++;
            Instrumentation.Total.ForcesApplied++;
		}

		/// <summary>Signals that a penetration between two bodies has been detected</summary>
		[Conditional("DEBUG")]
		public static void PenetrationDetected()
		{
			Instrumentation.Current.PenetrationsDetected++;
			Instrumentation.Total.PenetrationsDetected++;
		}

		/// <summary>Signals that new call to Simulation.Update has been made</summary>
		[Conditional("DEBUG")]
		public static void NewUpdate()
		{
            Instrumentation.Current.Updates++;
            Instrumentation.Total.Updates++;
            Instrumentation.Last = Instrumentation.Current;
			Instrumentation.Current = default(Data);
		} 
		#endregion
	}
}
