/* Copyright (c) 2008 John Wells - http://www.codeplex.com/Johnnylightbulb/

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation
files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use,
copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. */

namespace JohnWells.GameDynamics
{
    // .NET Fx
    using System;
    using System.Collections;
    using System.Collections.Generic;
    using System.Diagnostics;
    using System.Runtime.InteropServices;

    // XNA
    using Microsoft.Xna.Framework;

    public abstract partial class Sap
    {
        /// <summary>Used for the GetEnumerator method</summary>
        /// <remarks>When possible and practical, specifically enumerating through this type
        /// (instead of IEnumerable) can prevent some GC costs associated with boxing</remarks>
        [StructLayout(LayoutKind.Auto)]
        public struct Enumerator : IEnumerable<Body>, IEnumerator<Body>
        {
            #region Fields
            // Private variables
            private readonly Sap instance;
            private readonly int version;
            private int index;
            private Body current;
            #endregion

            internal Enumerator(Sap instance)
            {
                #region Assertions
                Debug.Assert(instance != null);
                Debug.Assert(instance.bodies != null);
                Debug.Assert(instance.markers != null);
                Debug.Assert(instance.count <= instance.bodies.Length);
                Debug.Assert(instance.bodies.Length == instance.markers.Length);
	            #endregion

                this.instance = instance;
                this.version = instance.version;
                this.index = 0;
                this.current = null;
            }

            #region Methods
            public Body Current
            {
                get { return this.current; }
            }

            public Enumerator GetEnumerator()
            {
                return this;
            }

            public bool MoveNext()
            {
                #region Assertions
                // Always make sure the instance hasn't been modified out from under us...
                Debug.Assert(this.instance.version == version, "Collection was modified; enumeration operation may not execute.");
                #endregion

                if (this.index < this.instance.count)
				{
					// TODO: Instrument
                    // Current becomes the body of the current entry and index is incremented
                    // for next time..
                    this.current = this.instance.bodies[this.index++];
                    return true;
                }
                else
                    return false;
            } 
            #endregion

            #region IEnumerable<Body> Members
            IEnumerator<Body> IEnumerable<Body>.GetEnumerator()
            {
                return this;
            }

            IEnumerator IEnumerable.GetEnumerator()
            {
                return this;
            }
            #endregion

            #region IEnumerator<Body> Members
            Body IEnumerator<Body>.Current
            {
                get { return this.Current; }
            }

            void IDisposable.Dispose()
            {
            }

            object IEnumerator.Current
            {
                get { return this.Current; }
            }

            bool IEnumerator.MoveNext()
            {
                return this.MoveNext();
            }

            void IEnumerator.Reset()
            {
                this.index = 0;
                this.current = null;
            }
            #endregion
        }
    }
}
